pyxmpp.sasl.plain

Package pyxmpp :: Package sasl :: Module plain |
[hide private]

# Module plain

source code

PLAIN authentication mechanism for PyXMPP SASL implementation.

Normative reference:
  - RFC 2595

Classes | [hide private]
| PlainClientAuthenticator Provides PLAIN SASL authentication for a client.
| PlainServerAuthenticator Provides PLAIN SASL authentication for a server.

Variables | [hide private]
| __revision__ = ``'``$Id: plain.py 714 2010-04-05 10:20:10Z jajcus $``'``
| __package__ = ``'``pyxmpp.sasl``'``

Imports: logging, to_utf8, from_utf8, ClientAuthenticator, ServerAuthenticator, Success, Failure, Challenge, Response